pub enum Scope {
Show 17 variants
Full,
Acl,
AclReadonly,
AppCreated,
Calendarlist,
CalendarlistReadonly,
Calendar,
CalendarReadonly,
Event,
EventFreebusy,
EventOwned,
EventOwnedReadonly,
EventPublicReadonly,
EventReadonly,
Freebusy,
Readonly,
SettingReadonly,
}Expand description
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.
Variants
Full
See, edit, share, and permanently delete all the calendars you can access using Google Calendar
Acl
See and change the sharing permissions of Google calendars you own
AclReadonly
See the sharing permissions of Google calendars you own
AppCreated
Make secondary Google calendars, and see, create, change, and delete events on them
Calendarlist
See, add, and remove Google calendars you’re subscribed to
CalendarlistReadonly
See the list of Google calendars you’re subscribed to
Calendar
See and change the properties of Google calendars you have access to, and create secondary calendars
CalendarReadonly
See the title, description, default time zone, and other properties of Google calendars you have access to
Event
View and edit events on all your calendars
EventFreebusy
See the availability on Google calendars you have access to
EventOwned
See, create, change, and delete events on Google calendars you own
EventOwnedReadonly
See the events on Google calendars you own
EventPublicReadonly
See the events on public calendars
EventReadonly
View events on all your calendars
Freebusy
View your availability in your calendars
Readonly
See and download any calendar you can access using your Google Calendar
SettingReadonly
View your Calendar settings