AclRule

Struct AclRule 

pub struct AclRule {
    pub etag: Option<String>,
    pub id: Option<String>,
    pub kind: Option<String>,
    pub role: Option<String>,
    pub scope: Option<AclRuleScope>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

etag: Option<String>

ETag of the resource.

id: Option<String>

Identifier of the Access Control List (ACL) rule. See Sharing calendars.

kind: Option<String>

Type of the resource (“calendar#aclRule”).

role: Option<String>

The role assigned to the scope. Possible values are:

  • “none” - Provides no access.
  • “freeBusyReader” - Provides read access to free/busy information.
  • “reader” - Provides read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
  • “writer” - Provides read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible. Provides read access to the calendar’s ACLs.
  • “owner” - Provides manager access to the calendar. This role has all of the permissions of the writer role with the additional ability to modify access levels of other users. Important: the owner role is different from the calendar’s data owner. A calendar has a single data owner, but can have multiple users with owner role.
scope: Option<AclRuleScope>

The extent to which calendar access is granted by this ACL rule.