pub struct Calendar {
pub auto_accept_invitations: Option<bool>,
pub conference_properties: Option<ConferenceProperties>,
pub data_owner: Option<String>,
pub description: Option<String>,
pub etag: Option<String>,
pub id: Option<String>,
pub kind: Option<String>,
pub location: Option<String>,
pub summary: Option<String>,
pub time_zone: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- clear calendars (none)
- delete calendars (none)
- get calendars (response)
- insert calendars (request|response)
- patch calendars (request|response)
- update calendars (request|response)
Fields
auto_accept_invitations: Option<bool>Whether this calendar automatically accepts invitations. Only valid for resource calendars.
conference_properties: Option<ConferenceProperties>Conferencing properties for this calendar, for example what types of conferences are allowed.
data_owner: Option<String>The email of the owner of the calendar. Set only for secondary calendars. Read-only.
description: Option<String>Description of the calendar. Optional.
etag: Option<String>ETag of the resource.
id: Option<String>Identifier of the calendar. To retrieve IDs call the calendarList.list() method.
kind: Option<String>Type of the resource (“calendar#calendar”).
location: Option<String>Geographic location of the calendar as free-form text. Optional.
summary: Option<String>Title of the calendar.
time_zone: Option<String>The time zone of the calendar. (Formatted as an IANA Time Zone Database name, e.g. “Europe/Zurich”.) Optional.