EventAttendee

Struct EventAttendee 

pub struct EventAttendee {
    pub additional_guests: Option<i32>,
    pub comment: Option<String>,
    pub display_name: Option<String>,
    pub email: Option<String>,
    pub id: Option<String>,
    pub optional: Option<bool>,
    pub organizer: Option<bool>,
    pub resource: Option<bool>,
    pub response_status: Option<String>,
    pub self_: Option<bool>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

additional_guests: Option<i32>

Number of additional guests. Optional. The default is 0.

comment: Option<String>

The attendee’s response comment. Optional.

display_name: Option<String>

The attendee’s name, if available. Optional.

email: Option<String>

The attendee’s email address, if available. This field must be present when adding an attendee. It must be a valid email address as per RFC5322. Required when adding an attendee.

id: Option<String>

The attendee’s Profile ID, if available.

optional: Option<bool>

Whether this is an optional attendee. Optional. The default is False.

organizer: Option<bool>

Whether the attendee is the organizer of the event. Read-only. The default is False.

resource: Option<bool>

Whether the attendee is a resource. Can only be set when the attendee is added to the event for the first time. Subsequent modifications are ignored. Optional. The default is False.

response_status: Option<String>

The attendee’s response status. Possible values are:

  • “needsAction” - The attendee has not responded to the invitation (recommended for new events).
  • “declined” - The attendee has declined the invitation.
  • “tentative” - The attendee has tentatively accepted the invitation.
  • “accepted” - The attendee has accepted the invitation. Warning: If you add an event using the values declined, tentative, or accepted, attendees with the “Add invitations to my calendar” setting set to “When I respond to invitation in email” or “Only if the sender is known” might have their response reset to needsAction and won’t see an event in their calendar unless they change their response in the event invitation email. Furthermore, if more than 200 guests are invited to the event, response status is not propagated to the guests.
self_: Option<bool>

Whether this entry represents the calendar on which this copy of the event appears. Read-only. The default is False.