pub struct EventFocusTimeProperties {
pub auto_decline_mode: Option<String>,
pub chat_status: Option<String>,
pub decline_message: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
auto_decline_mode: Option<String>Whether to decline meeting invitations which overlap Focus Time events. Valid values are declineNone, meaning that no meeting invitations are declined; declineAllConflictingInvitations, meaning that all conflicting meeting invitations that conflict with the event are declined; and declineOnlyNewConflictingInvitations, meaning that only new conflicting meeting invitations which arrive while the Focus Time event is present are to be declined.
chat_status: Option<String>The status to mark the user in Chat and related products. This can be available or doNotDisturb.
decline_message: Option<String>Response message to set if an existing event or new invitation is automatically declined by Calendar.