pub struct EventWorkingLocationPropertiesCustomLocation {
pub label: Option<String>,
}Expand description
If present, specifies that the user is working from a custom location.
This type is not used in any activity, and only used as part of another schema.
Fields
label: Option<String>An optional extra label for additional information.