pub struct CalendarMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on calendar resources.
It is not used directly, but through the CalendarHub hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_calendar3 as calendar3;
use calendar3::{CalendarHub, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CalendarHub::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `clear(...)`, `delete(...)`, `get(...)`, `insert(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.calendars();Implementations
Sourceimpl<'a, C> CalendarMethods<'a, C>
impl<'a, C> CalendarMethods<'a, C>
Sourcepub fn clear(&self, calendar_id: &str) -> CalendarClearCall<'a, C>
pub fn clear(&self, calendar_id: &str) -> CalendarClearCall<'a, C>
Create a builder to help you perform the following task:
Clears a primary calendar. This operation deletes all events associated with the primary calendar of an account.
Arguments
calendarId- Calendar identifier. To retrieve calendar IDs call the calendarList.list method. If you want to access the primary calendar of the currently logged in user, use the “primary” keyword.
Sourcepub fn delete(&self, calendar_id: &str) -> CalendarDeleteCall<'a, C>
pub fn delete(&self, calendar_id: &str) -> CalendarDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a secondary calendar. Use calendars.clear for clearing all events on primary calendars.
Arguments
calendarId- Calendar identifier. To retrieve calendar IDs call the calendarList.list method. If you want to access the primary calendar of the currently logged in user, use the “primary” keyword.
Sourcepub fn get(&self, calendar_id: &str) -> CalendarGetCall<'a, C>
pub fn get(&self, calendar_id: &str) -> CalendarGetCall<'a, C>
Create a builder to help you perform the following task:
Returns metadata for a calendar.
Arguments
calendarId- Calendar identifier. To retrieve calendar IDs call the calendarList.list method. If you want to access the primary calendar of the currently logged in user, use the “primary” keyword.
Sourcepub fn insert(&self, request: Calendar) -> CalendarInsertCall<'a, C>
pub fn insert(&self, request: Calendar) -> CalendarInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a secondary calendar. The authenticated user for the request is made the data owner of the new calendar.
Note: We recommend to authenticate as the intended data owner of the calendar. You can use domain-wide delegation of authority to allow applications to act on behalf of a specific user. Don’t use a service account for authentication. If you use a service account for authentication, the service account is the data owner, which can lead to unexpected behavior. For example, if a service account is the data owner, data ownership cannot be transferred.
Arguments
request- No description provided.
Sourcepub fn patch(
&self,
request: Calendar,
calendar_id: &str,
) -> CalendarPatchCall<'a, C>
pub fn patch( &self, request: Calendar, calendar_id: &str, ) -> CalendarPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates metadata for a calendar. This method supports patch semantics.
Arguments
request- No description provided.calendarId- Calendar identifier. To retrieve calendar IDs call the calendarList.list method. If you want to access the primary calendar of the currently logged in user, use the “primary” keyword.
Sourcepub fn update(
&self,
request: Calendar,
calendar_id: &str,
) -> CalendarUpdateCall<'a, C>
pub fn update( &self, request: Calendar, calendar_id: &str, ) -> CalendarUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates metadata for a calendar.
Arguments
request- No description provided.calendarId- Calendar identifier. To retrieve calendar IDs call the calendarList.list method. If you want to access the primary calendar of the currently logged in user, use the “primary” keyword.