pub struct EventBirthdayProperties {
pub contact: Option<String>,
pub custom_type_name: Option<String>,
pub type_: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
contact: Option<String>Resource name of the contact this birthday event is linked to. This can be used to fetch contact details from People API. Format: “people/c12345”. Read-only.
custom_type_name: Option<String>Custom type label specified for this event. This is populated if birthdayProperties.type is set to “custom”. Read-only.
type_: Option<String>Type of birthday or special event. Possible values are:
- “anniversary” - An anniversary other than birthday. Always has a contact.
- “birthday” - A birthday event. This is the default value.
- “custom” - A special date whose label is further specified in the customTypeName field. Always has a contact.
- “other” - A special date which does not fall into the other categories, and does not have a custom label. Always has a contact.
- “self” - Calendar owner’s own birthday. Cannot have a contact. The Calendar API only supports creating events with the type “birthday”. The type cannot be changed after the event is created.